#!/bin/bash

if [ "$1" == "test" ]; then
  POSTFIX="-test"
  IMAGE_TAG=${CI_COMMIT_SHA}
else
  POSTFIX=""
fi

if [ "$IMAGE_TAG" == "" ]; then
  echo "Make sure IMAGE_TAG is set"
  exit 1
fi

IMAGE_NAME=gitea.hottis.de/moerp/elo-rezept-rechner
NAMESPACE=moerp${POSTFIX}
DEPLOYMENT_DIR=$PWD/deployment

pushd $DEPLOYMENT_DIR > /dev/null
./decrypt-secrets.sh || exit 1 
. /tmp/secrets
rm /tmp/secrets

CLIENT_SECRETS=`cat oidc-config${POSTFIX}.json | sed -e's!%CLIENT_SECRET%!'$CLIENT_SECRET'!'`

kubectl create namespace $NAMESPACE \
  --dry-run=client \
  -o yaml | \
  kubectl -f - apply

kubectl create secret generic nutri-secrets \
  --dry-run=client \
  -o yaml \
  --save-config \
  --from-literal=SECRET="$SECRET" \
  --from-literal=CLIENT_SECRETS="$CLIENT_SECRETS" \
  --from-literal=PGUSER="$PGUSER" \
  --from-literal=PGPASSWORD="$PGPASSWORD" \
  --from-literal=PGDATABASE="$PGDATABASE" \
  --from-literal=PGHOST="timescaledb.database.svc.cluster.local" \
  --from-literal=PGSSLMODE="require" | \
  kubectl apply -f - -n $NAMESPACE

cat $DEPLOYMENT_DIR/deploy-yml.tmpl | \
  sed -e 's,%IMAGE%,'$IMAGE_NAME':'$IMAGE_TAG','g | \
  sed -e 's,%POSTFIX%,'$POSTFIX','g | \
  kubectl apply -f - -n $NAMESPACE

popd > /dev/null

